# Generated by Django 2.1.11 on 2019-10-21 09:58

from django.db import migrations
import django.db.models.manager


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0015_auto_20191001_0847'),
    ]

    operations = [
        migrations.AlterModelManagers(
            name='displaycolor',
            managers=[
                ('available_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.AlterModelManagers(
            name='issuetype',
            managers=[
                ('available_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.AlterModelManagers(
            name='projectstatus',
            managers=[
                ('available_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.AlterModelManagers(
            name='projecttype',
            managers=[
                ('available_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.AlterModelManagers(
            name='queue',
            managers=[
                ('available_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.AlterModelManagers(
            name='source',
            managers=[
                ('available_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.AlterModelManagers(
            name='subissuetype',
            managers=[
                ('available_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.AlterModelManagers(
            name='ticketpriority',
            managers=[
                ('available_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.AlterModelManagers(
            name='ticketstatus',
            managers=[
                ('available_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.AlterModelManagers(
            name='tickettype',
            managers=[
                ('available_objects', django.db.models.manager.Manager()),
            ],
        ),
    ]
