# Generated by Django 3.1.7 on 2021-11-24 18:08

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0098_auto_20211029_1641'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='contract',
            options={'ordering': ('name',)},
        ),
        migrations.AlterField(
            model_name='contract',
            name='name',
            field=models.CharField(db_index=True, max_length=250),
        ),
    ]
