# Generated by Django 2.1.14 on 2020-01-30 12:18

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0037_subissuetype_parent_value'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='timeentry',
            options={'ordering': ('-start_date_time', 'id'), 'verbose_name_plural': 'Time entries'},
        ),
    ]
