# Generated by Django 4.2.11 on 2024-06-17 11:37

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0116_alter_servicecall_tasks_alter_servicecall_tickets'),
    ]

    operations = [
        migrations.AlterField(
            model_name='tasknote',
            name='task',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='notes', to='djautotask.task'),
        ),
        migrations.AlterField(
            model_name='ticketnote',
            name='ticket',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='notes', to='djautotask.ticket'),
        ),
    ]
