# Generated by Django 2.1.14 on 2020-02-05 16:51

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0043_department'),
        ('djautotask', '0043_timeentry_allocation_code'),
    ]

    operations = [
    ]
