# Generated by Django 3.1.4 on 2021-01-13 17:43

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0087_auto_20210108_1307'),
        ('djautotask', '0087_auto_20210108_1214'),
    ]

    operations = [
    ]
