# Generated by Django 4.0.10 on 2023-06-22 12:11

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0114_tasktype_tasktypetracker'),
    ]

    operations = [
        migrations.AddField(
            model_name='task',
            name='task_type',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='djautotask.tasktype'),
        ),
    ]
